Merge branch 'privatestaging' into p2p
Conflicts:
include/hcc_detail/hip_hcc.h
src/hip_hcc.cpp
[ROCm/hip commit: 49cc5aec91]
This commit is contained in:
@@ -451,7 +451,7 @@ private:
|
||||
void waitCopy(LockedAccessor_StreamCrit_t &crit, ihipSignal_t *signal);
|
||||
|
||||
// The unsigned return is hipMemcpyKind
|
||||
unsigned resolveMemcpyDirection(bool srcInDeviceMem, bool dstInDeviceMem);
|
||||
unsigned resolveMemcpyDirection(bool srcTracked, bool dstTracked, bool srcInDeviceMem, bool dstInDeviceMem);
|
||||
void setAsyncCopyAgents(unsigned kind, ihipCommand_t *commandType, hsa_agent_t *srcAgent, hsa_agent_t *dstAgent);
|
||||
|
||||
unsigned _device_index; // index into the g_device array
|
||||
|
||||
@@ -401,6 +401,13 @@ __device__ int __all( int input);
|
||||
__device__ int __any( int input);
|
||||
__device__ unsigned long long int __ballot( int input);
|
||||
|
||||
// __ldg function
|
||||
template <typename T>
|
||||
__device__ __forceinline__ T __ldg( const T * addr)
|
||||
{
|
||||
return *addr;
|
||||
}
|
||||
|
||||
// warp shuffle functions
|
||||
#ifdef __cplusplus
|
||||
|
||||
|
||||
Reference in New Issue
Block a user